pub enum Context {
View(ViewRef),
}Expand description
The region from which injection is attempted for injected events. As the context, it serves two purposes: (1) Scoping. It confirms the |Device|’s authority to inject pointer events on the specified target. Specifically, the context must be a view-tree ancestor of the target. (2) Coordinate System. It provides the reference coordinate system to define the viewport’s position and size, relative to the target.
Variants