pub struct Device;Expand description
The type corresponding to the Device protocol. The channel for injecting pointer events into a target. The associated |Config| applies to injected pointer events.
A |Device| may inject pointer events into a target in the scene, but the dispatch of pointer events to UI clients within that target’s view tree will depend on the dispatch policy and the scene topology.